From 467623d19e5ea4e3dab66a19c40e503da673b7f8 Mon Sep 17 00:00:00 2001
From: Claudio Scafuri <claudio.scafuri@elettra.eu>
Date: Thu, 20 Feb 2020 09:53:14 +0100
Subject: [PATCH] correcte attribute name: MCPLLStatus_S7_7 -> MCPLLStatus_S5_7

---
 src/GofGateway.py  | 14 +++++++-------
 src/GofGateway.xmi |  2 +-
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/GofGateway.xmi b/src/GofGateway.xmi
index fc7cc1e..9b9a24b 100644
--- a/src/GofGateway.xmi
+++ b/src/GofGateway.xmi
@@ -37,7 +37,7 @@
       <readExcludedStates>UNKNOWN</readExcludedStates>
       <readExcludedStates>INIT</readExcludedStates>
     </attributes>
-    <attributes name="MCPLLStatus_S7_7" attType="Scalar" rwType="READ" displayLevel="OPERATOR" polledPeriod="0" maxX="" maxY="" allocReadMember="true" isDynamic="false">
+    <attributes name="MCPLLStatus_S5_7" attType="Scalar" rwType="READ" displayLevel="OPERATOR" polledPeriod="0" maxX="" maxY="" allocReadMember="true" isDynamic="false">
       <dataType xsi:type="pogoDsl:BooleanType"/>
       <changeEvent fire="false" libCheckCriteria="false"/>
       <archiveEvent fire="false" libCheckCriteria="false"/>
diff --git a/src/GofGateway.py b/src/GofGateway.py
index f7e4841..04e1ec7 100755
--- a/src/GofGateway.py
+++ b/src/GofGateway.py
@@ -59,7 +59,7 @@ class GofGateway(Device):
         label="BPM S1.7/MCPPLStatus",
     )
 
-    MCPLLStatus_S7_7 = attribute(
+    MCPLLStatus_S5_7 = attribute(
         dtype='bool',
         label="BPM S5.7/MCPPLStatus",
     )
@@ -193,15 +193,15 @@ class GofGateway(Device):
         return self.get_state() not in [DevState.UNKNOWN,DevState.INIT]
         # PROTECTED REGION END #    //  GofGateway.is_MCPLLStatus_S1_7_allowed
 
-    def read_MCPLLStatus_S7_7(self):
-        # PROTECTED REGION ID(GofGateway.MCPLLStatus_S7_7_read) ENABLED START #
+    def read_MCPLLStatus_S5_7(self):
+        # PROTECTED REGION ID(GofGateway.MCPLLStatus_S5_7_read) ENABLED START #
         return self.bpm57.read().value
-        # PROTECTED REGION END #    //  GofGateway.MCPLLStatus_S7_7_read
+        # PROTECTED REGION END #    //  GofGateway.MCPLLStatus_S5_7_read
 
-    def is_MCPLLStatus_S7_7_allowed(self, attr):
-        # PROTECTED REGION ID(GofGateway.is_MCPLLStatus_S7_7_allowed) ENABLED START #
+    def is_MCPLLStatus_S5_7_allowed(self, attr):
+        # PROTECTED REGION ID(GofGateway.is_MCPLLStatus_S5_7_allowed) ENABLED START #
         return self.get_state() not in [DevState.UNKNOWN,DevState.INIT]
         # PROTECTED REGION END #    //  GofGateway.is_MCPLLStatus_S7_7_allowed
 
     def read_MCPLLStatus_S9_7(self):
         # PROTECTED REGION ID(GofGateway.MCPLLStatus_S9_7_read) ENABLED START #
@@ -193,15 +193,15 @@ class GofGateway(Device):
         return self.get_state() not in [DevState.UNKNOWN,DevState.INIT]
-        # PROTECTED REGION END #    //  GofGateway.is_MCPLLStatus_S7_7_allowed
+        # PROTECTED REGION END #    //  GofGateway.is_MCPLLStatus_S5_7_allowed
 
     def read_MCPLLStatus_S9_7(self):
-- 
GitLab